@@ -38,12 +38,29 @@ except Exception:
 
 from hoss_agent.base import Client
 from hoss_agent.instrumentation.control import instrument
+from hoss_agent.utils.logging import get_logger
 
 GLOBAL_CLIENT = None
+logger = get_logger("hoss_agent")
 
 
-def init(config=None, **inline):
-    client = Client(config, **inline)
+def init(config=None, *args, **inline):
+
+    if isinstance(config, str):
+        if len(config) == 0:
+            logger.info('Hoss API Key is not provided. Exiting')
+            return
+        if len(args) >= 1 and isinstance(args[0], dict):
+            args[0]['API_KEY'] = config
+            client = Client(args[0], **inline)
+        else:
+            client = Client({"API_KEY": config}, **inline)
+    else:
+        if not config or not config['API_KEY']:
+            logger.info('Hoss API Key is not provided. Exiting')
+            return
+        client = Client(config, **inline)
+
     client.instrument()
     client.start_threads()
     global GLOBAL_CLIENT
