@@ -11,8 +11,11 @@ class BufferProxy(wrapt.ObjectProxy):
     def __iter__(self):
         it = iter(self.__wrapped__)
         for chunk in it:
-            if isinstance(chunk, str):
-                self.__target__.write(chunk.encode("utf-8"))
-            else:
-                self.__target__.write(chunk)
+            try:
+                if isinstance(chunk, str):
+                    self.__target__.write(chunk.encode("utf-8"))
+                else:
+                    self.__target__.write(chunk)
+            except:
+                pass
             yield chunk
